@@ -34,7 +34,7 @@ with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include <geoclue/gc-iface-address.h>
 
 /* Soup */
-#include <libsoup/soup.h>
+#include <libsoup/soup-gnome.h>
 
 /* Network Manager */
 #include <nm-client.h>
@@ -252,6 +252,7 @@ ubuntu_geoip_provider_init (UbuntuGeoipProvider *self)
 	/* Allocate */
 	if (test_data == NULL) {
 		self->priv->soup = soup_session_async_new();
+		soup_session_add_feature_by_type(self->priv->soup, soup_proxy_resolver_default_get_type());
 		self->priv->client = nm_client_new();
 		g_signal_connect(G_OBJECT(self->priv->client), "notify::" NM_CLIENT_STATE, G_CALLBACK(nm_state_change), self);
 
@@ -612,8 +613,8 @@ parse_xml_data (UbuntuGeoipProvider * provider, const gchar * xml, const gint le
 
 		GeoclueAccuracy * accuracy = position_accuracy_build(provider);
 		gc_iface_position_emit_position_changed(GC_IFACE_POSITION(provider), 
-		                                        time(NULL),
 		                                        GEOCLUE_POSITION_FIELDS_LATITUDE | GEOCLUE_POSITION_FIELDS_LONGITUDE,
+		                                        time(NULL),
 		                                        provider->priv->latitude,
 		                                        provider->priv->longitude,
 		                                        0, /* Altitude */
@@ -1021,6 +1022,14 @@ markup_text (GMarkupParseContext * context, const gchar * text, gsize text_len,
 	return;
 }
 
+static void
+sigterm_graceful_exit (int signal)
+{
+	g_warning("SIGTERM recieved");
+	g_main_loop_quit(mainloop);
+	return;
+}
+
 static GOptionEntry general_options[] = {
 	{"test-data",  0,  0,  G_OPTION_ARG_FILENAME,  &test_data,  "Path to test data to use instead of getting it from the network", "XML Data File"},
 	{NULL}
@@ -1033,7 +1042,9 @@ main (int argc, char * argv[])
 	GError * error = NULL;
 	GOptionContext * context;
 
+#ifndef GLIB_VERSION_2_36
 	g_type_init();
+#endif
 
 	context = g_option_context_new("- Get the location of the machine using GeoIP and report it through GeoClue");
 
@@ -1050,6 +1061,8 @@ main (int argc, char * argv[])
 
 	mainloop = g_main_loop_new(NULL, TRUE);
 
+	signal(SIGTERM, sigterm_graceful_exit);
+
 	g_main_loop_run(mainloop);
 
 	g_main_loop_unref(mainloop);
